Class: Spree::Api::V3::Admin::WebhookEndpointSerializer
- Inherits:
-
BaseSerializer
- Object
- BaseSerializer
- Spree::Api::V3::Admin::WebhookEndpointSerializer
- Defined in:
- app/serializers/spree/api/v3/admin/webhook_endpoint_serializer.rb
Overview
Admin API serializer for WebhookEndpoint.
Never exposes ‘secret_key` outside of the create response (encrypted at rest, plaintext only in memory after generation). The full secret is delivered exactly once via #secret_key below — `nil` everywhere else.
Method Summary
Methods inherited from BaseSerializer
#current_currency, #current_locale, #current_store, #current_user, #expand?, #expands, #nested_expands_for, #nested_params